==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/SideEffectTagger.h <==
// public class soot.jimple.toolkits.pointer.SideEffectTagger

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 6671e7f7c0549001 soot_jimple_toolkits_pointer_SideEffectTagger

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_pointer_SideEffectTagger_H_
#define _JC_soot_jimple_toolkits_pointer_SideEffectTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vmethods	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtable	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$initializationStuff$6de08568b8133ac5(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$keyFor$ee671bb52371d4b1(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method_info$initializationStuff$6de08568b8133ac5;
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method_info$keyFor$ee671bb52371d4b1;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$v$4f93456a2cfbc6c7(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vmethods {
	void	(*initializationStuff$6de08568b8133ac5)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_java_lang_String$object *);
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*keyFor$ee671bb52371d4b1)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vmethods	soot_jimple_toolkits_pointer_SideEffectTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_refs {
	struct _jc_java_util_Date$object	*startTime;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$refs {
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_refs	soot_jimple_toolkits_pointer_SideEffectTagger;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_nonrefs {
	jint	numRWs;
	jint	numWRs;
	jint	numRRs;
	jint	numWWs;
	jint	numNatives;
	jboolean	optionNaive;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_nonrefs	soot_jimple_toolkits_pointer_SideEffectTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object {
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype _jc_soot_jimple_toolkits_pointer_SideEffectTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_SideEffectTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_SideEffectTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_SideEffectTagger_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/SideEffectTagger.h <==
// public class soot.jimple.toolkits.pointer.SideEffectTagger

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 6671e7f7c0549001 soot_jimple_toolkits_pointer_SideEffectTagger

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_pointer_SideEffectTagger_H_
#define _JC_soot_jimple_toolkits_pointer_SideEffectTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vmethods	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtable	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$initializationStuff$6de08568b8133ac5(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$keyFor$ee671bb52371d4b1(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method_info$initializationStuff$6de08568b8133ac5;
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger$method_info$keyFor$ee671bb52371d4b1;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger$method$v$4f93456a2cfbc6c7(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vmethods {
	void	(*initializationStuff$6de08568b8133ac5)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*keyFor$ee671bb52371d4b1)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vmethods	soot_jimple_toolkits_pointer_SideEffectTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_refs {
	struct _jc_java_util_Date$object	*startTime;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$refs {
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_refs	soot_jimple_toolkits_pointer_SideEffectTagger;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_nonrefs {
	jint	numRWs;
	jint	numWRs;
	jint	numRRs;
	jint	numWWs;
	jint	numNatives;
	jboolean	optionNaive;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger$sub_nonrefs	soot_jimple_toolkits_pointer_SideEffectTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object {
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_SideEffectTagger$vtype _jc_soot_jimple_toolkits_pointer_SideEffectTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_SideEffectTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_SideEffectTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_SideEffectTagger_H_ */
